diff --git a/java/webclient/classes/Makefile.unix b/java/webclient/classes/Makefile.unix
index e1720478405e..b45614f8b783 100644
--- a/java/webclient/classes/Makefile.unix
+++ b/java/webclient/classes/Makefile.unix
@@ -19,6 +19,6 @@ all:
${JAVAH} -jni -classpath ${CLASSES} \
-o ${JAVAH_OUTPUT_DIR}/motif/MotifBrowserControlCanvas.h org.mozilla.webclient.motif.MotifBrowserControlCanvas
${JAVAH} -jni -classpath ${CLASSES} \
- -o ${JAVAH_OUTPUT_DIR}/motif/MozillaEventThread.h org.mozilla.webclient.motif.MozillaEventThread
+ -o ${JAVAH_OUTPUT_DIR}/motif/MozillaEventThread.h org.mozilla.webclient.motif.NativeEventThread
${JAVAH} -jni -classpath ${CLASSES} \
- -o ${JAVAH_OUTPUT_DIR}/BrowserControlMozillaShim.h org.mozilla.webclient.BrowserControlMozillaShim
+ -o ${JAVAH_OUTPUT_DIR}/BrowserControlNativeShim.h org.mozilla.webclient.BrowserControlNativeShim
diff --git a/java/webclient/classes/org/mozilla/webclient/BrowserControlFactory.java b/java/webclient/classes/org/mozilla/webclient/BrowserControlFactory.java
index 85db548d8809..da0fa42d7d61 100644
--- a/java/webclient/classes/org/mozilla/webclient/BrowserControlFactory.java
+++ b/java/webclient/classes/org/mozilla/webclient/BrowserControlFactory.java
@@ -43,7 +43,7 @@ import java.io.FileNotFoundException;
* This is a static class, it is neven instantiated.
*
- * @version $Id: BrowserControlFactory.java,v 1.2 1999/12/06 23:31:04 edburns%acm.org Exp $
+ * @version $Id: BrowserControlFactory.java,v 1.3 1999/12/23 04:09:27 edburns%acm.org Exp $
*
* @see org.mozilla.webclient.test.EmbeddedMozilla
@@ -153,7 +153,7 @@ public static void setAppData(String absolutePathToNativeBrowserBinDir) throws F
}
try {
- BrowserControlMozillaShim.initialize(absolutePathToNativeBrowserBinDir);
+ BrowserControlNativeShim.initialize(absolutePathToNativeBrowserBinDir);
}
catch (Exception e) {
throw new ClassNotFoundException("Can't initialize native browser: " +
@@ -197,7 +197,7 @@ public static void main(String [] args)
Assert.setEnabled(true);
Log.setApplicationName("BrowserControlFactory");
Log.setApplicationVersion("0.0");
- Log.setApplicationVersionDate("$Id: BrowserControlFactory.java,v 1.2 1999/12/06 23:31:04 edburns%acm.org Exp $");
+ Log.setApplicationVersionDate("$Id: BrowserControlFactory.java,v 1.3 1999/12/23 04:09:27 edburns%acm.org Exp $");
java.awt.Canvas canvas = null;
BrowserControl control = null;
diff --git a/java/webclient/classes/org/mozilla/webclient/BrowserControlImpl.java b/java/webclient/classes/org/mozilla/webclient/BrowserControlImpl.java
index 1127996d28d8..7f933af1d713 100644
--- a/java/webclient/classes/org/mozilla/webclient/BrowserControlImpl.java
+++ b/java/webclient/classes/org/mozilla/webclient/BrowserControlImpl.java
@@ -41,7 +41,7 @@ import java.awt.Canvas;
*
* Lifetime And Scope
*
- * @version $Id: BrowserControlImpl.java,v 1.6 1999/12/03 01:55:29 edburns%acm.org Exp $
+ * @version $Id: BrowserControlImpl.java,v 1.7 1999/12/23 04:09:27 edburns%acm.org Exp $
*
* @see org.mozilla.webclient.BrowserControl
*
@@ -98,7 +98,7 @@ protected BrowserControlImpl(Canvas yourCanvas)
public void createWindow(int windowPtr, Rectangle bounds) throws Exception
{
- nativeWebShell = BrowserControlMozillaShim.webShellCreate(windowPtr, bounds);
+ nativeWebShell = BrowserControlNativeShim.webShellCreate(windowPtr, bounds);
}
public Canvas getCanvas()
@@ -108,32 +108,32 @@ public Canvas getCanvas()
public void loadURL(String urlString) throws Exception
{
- BrowserControlMozillaShim.webShellLoadURL(nativeWebShell, urlString);
+ BrowserControlNativeShim.webShellLoadURL(nativeWebShell, urlString);
}
public void stop() throws Exception
{
- BrowserControlMozillaShim.webShellStop(nativeWebShell);
+ BrowserControlNativeShim.webShellStop(nativeWebShell);
}
public void show () throws Exception
{
- BrowserControlMozillaShim.webShellShow(nativeWebShell);
+ BrowserControlNativeShim.webShellShow(nativeWebShell);
}
public void hide () throws Exception
{
- BrowserControlMozillaShim.webShellHide(nativeWebShell);
+ BrowserControlNativeShim.webShellHide(nativeWebShell);
}
public void setBounds (Rectangle bounds) throws Exception
{
- BrowserControlMozillaShim.webShellSetBounds(nativeWebShell, bounds);
+ BrowserControlNativeShim.webShellSetBounds(nativeWebShell, bounds);
}
public void moveTo (int x, int y) throws Exception
{
- BrowserControlMozillaShim.webShellMoveTo(nativeWebShell, x, y);
+ BrowserControlNativeShim.webShellMoveTo(nativeWebShell, x, y);
}
/**
@@ -141,7 +141,7 @@ public void moveTo (int x, int y) throws Exception
*/
public void setFocus () throws Exception
{
- BrowserControlMozillaShim.webShellSetFocus(nativeWebShell);
+ BrowserControlNativeShim.webShellSetFocus(nativeWebShell);
}
/**
@@ -149,7 +149,7 @@ public void setFocus () throws Exception
*/
public void removeFocus () throws Exception
{
- BrowserControlMozillaShim.webShellRemoveFocus(nativeWebShell);
+ BrowserControlNativeShim.webShellRemoveFocus(nativeWebShell);
}
/**
@@ -157,7 +157,7 @@ public void removeFocus () throws Exception
*/
public void repaint (boolean forceRepaint) throws Exception
{
- BrowserControlMozillaShim.webShellRepaint(nativeWebShell, forceRepaint);
+ BrowserControlNativeShim.webShellRepaint(nativeWebShell, forceRepaint);
}
/**
@@ -165,7 +165,7 @@ public void repaint (boolean forceRepaint) throws Exception
*/
public boolean canBack () throws Exception
{
- return BrowserControlMozillaShim.webShellCanBack(nativeWebShell);
+ return BrowserControlNativeShim.webShellCanBack(nativeWebShell);
}
/**
@@ -173,7 +173,7 @@ public boolean canBack () throws Exception
*/
public boolean canForward () throws Exception
{
- return BrowserControlMozillaShim.webShellCanForward(nativeWebShell);
+ return BrowserControlNativeShim.webShellCanForward(nativeWebShell);
}
/**
@@ -181,7 +181,7 @@ public boolean canForward () throws Exception
*/
public boolean back () throws Exception
{
- return BrowserControlMozillaShim.webShellBack(nativeWebShell);
+ return BrowserControlNativeShim.webShellBack(nativeWebShell);
}
/**
@@ -189,7 +189,7 @@ public boolean back () throws Exception
*/
public boolean forward () throws Exception
{
- return BrowserControlMozillaShim.webShellForward(nativeWebShell);
+ return BrowserControlNativeShim.webShellForward(nativeWebShell);
}
/**
@@ -197,7 +197,7 @@ public boolean forward () throws Exception
*/
public boolean goTo (int historyIndex) throws Exception
{
- return BrowserControlMozillaShim.webShellGoTo(nativeWebShell, historyIndex);
+ return BrowserControlNativeShim.webShellGoTo(nativeWebShell, historyIndex);
}
/**
@@ -205,7 +205,7 @@ public boolean goTo (int historyIndex) throws Exception
*/
public int getHistoryLength () throws Exception
{
- return BrowserControlMozillaShim.webShellGetHistoryLength(nativeWebShell);
+ return BrowserControlNativeShim.webShellGetHistoryLength(nativeWebShell);
}
/**
@@ -213,7 +213,7 @@ public int getHistoryLength () throws Exception
*/
public int getHistoryIndex () throws Exception
{
- return BrowserControlMozillaShim.webShellGetHistoryIndex(nativeWebShell);
+ return BrowserControlNativeShim.webShellGetHistoryIndex(nativeWebShell);
}
/**
@@ -221,7 +221,7 @@ public int getHistoryIndex () throws Exception
*/
public String getURL (int historyIndex) throws Exception
{
- return BrowserControlMozillaShim.webShellGetURL(nativeWebShell, historyIndex);
+ return BrowserControlNativeShim.webShellGetURL(nativeWebShell, historyIndex);
}
/**
@@ -229,7 +229,7 @@ public String getURL (int historyIndex) throws Exception
*/
public boolean refresh() throws Exception
{
- return BrowserControlMozillaShim.webShellRefresh(nativeWebShell);
+ return BrowserControlNativeShim.webShellRefresh(nativeWebShell);
}
/**
@@ -244,7 +244,7 @@ public EventRegistration getEventRegistration() {
* add document load event listener
*/
public boolean addDocumentLoadListener(DocumentLoadListener dll) throws Exception {
- return BrowserControlMozillaShim.webShellAddDocListener(nativeWebShell, dll);
+ return BrowserControlNativeShim.webShellAddDocListener(nativeWebShell, dll);
}
/**
@@ -261,7 +261,7 @@ public int getNativeWebShell ()
public void finalize ()
{
try {
- BrowserControlMozillaShim.webShellDelete(nativeWebShell);
+ BrowserControlNativeShim.webShellDelete(nativeWebShell);
}
catch (Exception ex) {
System.out.println(ex.toString());
@@ -281,7 +281,7 @@ public static void main(String [] args)
// BrowserControlImpl me = new BrowserControlImpl();
Log.setApplicationName("BrowserControlImpl");
Log.setApplicationVersion("0.0");
- Log.setApplicationVersionDate("$Id: BrowserControlImpl.java,v 1.6 1999/12/03 01:55:29 edburns%acm.org Exp $");
+ Log.setApplicationVersionDate("$Id: BrowserControlImpl.java,v 1.7 1999/12/23 04:09:27 edburns%acm.org Exp $");
}
diff --git a/java/webclient/classes/org/mozilla/webclient/BrowserControlMozillaShim.java b/java/webclient/classes/org/mozilla/webclient/BrowserControlNativeShim.java
similarity index 65%
rename from java/webclient/classes/org/mozilla/webclient/BrowserControlMozillaShim.java
rename to java/webclient/classes/org/mozilla/webclient/BrowserControlNativeShim.java
index 5bfb8b715f85..01851d6ba5ec 100644
--- a/java/webclient/classes/org/mozilla/webclient/BrowserControlMozillaShim.java
+++ b/java/webclient/classes/org/mozilla/webclient/BrowserControlNativeShim.java
@@ -48,7 +48,7 @@ import java.awt.*;
* There is one instance of this class and all of the exposed methods
* are static.
- * @version $Id: BrowserControlMozillaShim.java,v 1.6 1999/11/06 02:24:18 dmose%mozilla.org Exp $
+ * @version $Id: BrowserControlNativeShim.java,v 1.1 1999/12/23 04:09:29 edburns%acm.org Exp $
*
* @see org.mozilla.webclient.BrowserControlImpl
@@ -56,7 +56,7 @@ import java.awt.*;
*/
-public class BrowserControlMozillaShim extends Object
+public class BrowserControlNativeShim extends Object
{
//
// Protected Constants
@@ -68,7 +68,7 @@ public class BrowserControlMozillaShim extends Object
private static boolean initialized = false;
-private static BrowserControlMozillaShim instance = null;
+private static BrowserControlNativeShim instance = null;
private static Object lock = null;
@@ -85,7 +85,7 @@ private static Object lock = null;
// Constructors and Initializers
//
-public BrowserControlMozillaShim()
+public BrowserControlNativeShim()
{
super();
lock = new Object();
@@ -105,7 +105,7 @@ public BrowserControlMozillaShim()
public static void initialize(String verifiedBinDirAbsolutePath) throws Exception
{
if (!initialized) {
- instance = new BrowserControlMozillaShim();
+ instance = new BrowserControlNativeShim();
instance.nativeInitialize(verifiedBinDirAbsolutePath);
initialized = true;
@@ -122,164 +122,6 @@ public static void terminate () throws Exception
}
}
-public static void processEvents(int theWebShell)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeProcessEvents(theWebShell);
- }
- }
-}
-
-//
-// Window events
-//
-
-public static void sendKeyDownEvent (int widgetPtr,
- char keyChar, int keyCode,
- int modifiers, int eventTime)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeSendKeyDownEvent(widgetPtr,
- keyChar, keyCode, modifiers,
- eventTime);
- }
- }
-}
-
-public static void sendKeyUpEvent (int widgetPtr,
- char keyChar, int keyCode,
- int modifiers, int eventTime)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeSendKeyUpEvent(widgetPtr, keyChar,
- keyCode, modifiers, eventTime);
-
- }
- }
-}
-
-public static void sendMouseEvent (int windowPtr, int widgetPtr,
- int widgetX, int widgetY,
- int windowX, int windowY,
- int mouseMessage, int numClicks,
- int modifiers, int eventTime)
-{
-
- synchronized(lock) {
- if (initialized) {
- instance.nativeSendMouseEvent(windowPtr, widgetPtr,
- widgetX, widgetY,
- windowX, windowY,
- mouseMessage, numClicks,
- modifiers, eventTime);
- }
- }
-}
-
-public static void idleEvent (int windowPtr)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeIdleEvent(windowPtr, 0);
- }
- }
-}
-
-public static void updateEvent (int windowPtr)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeUpdateEvent(windowPtr, 0);
- }
- }
-}
-
-//
-// Widget methods
-//
-
-public static int widgetCreate (int windowPtr,
- Rectangle bounds) throws Exception
-{
- synchronized(lock) {
- if (initialized) {
- return(instance.nativeWidgetCreate(windowPtr,
- bounds.x, bounds.y,
- bounds.width + 1, bounds.height + 1));
- } else {
- return 0;
- }
- }
-}
-
-public static void widgetDelete (int widgetPtr) throws Exception
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetDelete(widgetPtr);
- }
- }
-}
-
-public static void widgetResize (int widgetPtr, Rectangle bounds,
- boolean repaint)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetResize(widgetPtr, bounds.x, bounds.y, bounds.width + 1, bounds.height + 1, repaint);
- }
- }
-}
-
-public static void widgetResize (int widgetPtr, int width,
- int height, boolean repaint)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetResize(widgetPtr, 0, 0, width + 1, height + 1, repaint);
- }
- }
-}
-
-public static void widgetEnable (int widgetPtr, boolean enable)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetEnable(widgetPtr, enable);
- }
- }
-}
-
-public static void widgetShow (int widgetPtr, boolean show)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetShow(widgetPtr, show);
- }
- }
-}
-
-public static void widgetInvalidate (int widgetPtr, boolean isSynchronous)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetInvalidate(widgetPtr, isSynchronous);
- }
- }
-}
-
-public static void widgetUpdate (int widgetPtr)
-{
- synchronized(lock) {
- if (initialized) {
- instance.nativeWidgetUpdate(widgetPtr);
- }
- }
-}
-
//
// WebShell methods
//
@@ -525,43 +367,6 @@ public static boolean webShellRefresh(int webShellPtr) throws Exception
private native void nativeInitialize (String verifiedBinDirAbsolutePath) throws Exception;
private native void nativeTerminate () throws Exception;
-
-//
-// Event interfaces
-//
-
-private native void nativeSendKeyDownEvent(int widgetPtr, char keyChar, int keyCode, int modifiers, int eventTime);
-private native void nativeSendKeyUpEvent(int widgetPtr, char keyChar, int keyCode, int modifiers, int eventTime);
-private native void nativeSendMouseEvent(int windowPtr, int widgetPtr,
- int widgetX, int widgetY,
- int windowX, int windowY,
- int mouseMessage, int numClicks,
- int modifiers, int eventTime);
-private native void nativeProcessEvents(int theWebShell);
-private native void nativeIdleEvent (int windowPtr, int eventTime);
-private native void nativeUpdateEvent (int windowPtr, int eventTime);
-
-
-//
-// Widget interfaces
-//
-
-private native int nativeWidgetCreate (int windowPtr, int x, int y, int width, int height) throws Exception;
-private native void nativeWidgetDelete (int widgetPtr) throws Exception;
-private native boolean nativeWebShellAddDocListener(int windowPtr, DocumentLoadListener dl);
-private native void nativeWidgetResize (int widgetPtr, int x, int y, int width, int height, boolean repaint);
-
-/*
- private native void nativeWidgetResize (int widgetPtr, int width, int height, boolean repaint);
- */
-
-private native void nativeWidgetEnable (int widgetPtr, boolean enable);
-private native void nativeWidgetShow (int widgetPtr, boolean show);
-private native void nativeWidgetInvalidate (int widgetPtr, boolean isSynchronous);
-private native void nativeWidgetUpdate (int widgetPtr);
-
-
-
//
// WebShell interface
//
@@ -591,6 +396,7 @@ private native String nativeWebShellGetURL (int webShellPtr, int aHistoryIndex
* Added by Mark Goddard OTMP 9/2/1999
*/
private native boolean nativeWebShellRefresh (int webShellPtr) throws Exception;
+private native boolean nativeWebShellAddDocListener(int webShellPtr, DocumentLoadListener dl);
public static native void nativeDebugBreak(String fileName, int lineNumber);
@@ -607,13 +413,13 @@ public static native void nativeDebugBreak(String fileName, int lineNumber);
public static void main(String [] args)
{
Assert.setEnabled(true);
- BrowserControlMozillaShim me = new BrowserControlMozillaShim();
- Log.setApplicationName("BrowserControlMozillaShim");
+ BrowserControlNativeShim me = new BrowserControlNativeShim();
+ Log.setApplicationName("BrowserControlNativeShim");
Log.setApplicationVersion("0.0");
- Log.setApplicationVersionDate("$Id: BrowserControlMozillaShim.java,v 1.6 1999/11/06 02:24:18 dmose%mozilla.org Exp $");
+ Log.setApplicationVersionDate("$Id: BrowserControlNativeShim.java,v 1.1 1999/12/23 04:09:29 edburns%acm.org Exp $");
}
// ----UNIT_TEST_END
-} // end of class BrowserControlMozillaShim
+} // end of class BrowserControlNativeShim
diff --git a/java/webclient/classes/org/mozilla/webclient/motif/MotifBrowserControlCanvas.java b/java/webclient/classes/org/mozilla/webclient/motif/MotifBrowserControlCanvas.java
index 0166f804a0c1..052199f47539 100644
--- a/java/webclient/classes/org/mozilla/webclient/motif/MotifBrowserControlCanvas.java
+++ b/java/webclient/classes/org/mozilla/webclient/motif/MotifBrowserControlCanvas.java
@@ -36,7 +36,7 @@ import org.mozilla.util.ParameterCheck;
* There is one instance of the WebShellCanvas per top level awt Frame.
- * @version $Id: MotifBrowserControlCanvas.java,v 1.5 1999/12/06 23:31:05 edburns%acm.org Exp $
+ * @version $Id: MotifBrowserControlCanvas.java,v 1.6 1999/12/23 04:09:30 edburns%acm.org Exp $
*
* @see org.mozilla.webclient.BrowserControlCanvasFactory
*
@@ -132,8 +132,8 @@ public class MotifBrowserControlCanvas extends BrowserControlCanvas /* implement
this.gtkWinID = this.getGTKWinID(gtkWinPtr);
- Thread mozillaEventThread = new MozillaEventThread(this);
- mozillaEventThread.start();
+ Thread nativeEventThread = new NativeEventThread(this);
+ nativeEventThread.start();
}
return this.gtkWinPtr;
diff --git a/java/webclient/src/BrowserControlMozillaShim.cpp b/java/webclient/src/BrowserControlNativeShim.cpp
similarity index 71%
rename from java/webclient/src/BrowserControlMozillaShim.cpp
rename to java/webclient/src/BrowserControlNativeShim.cpp
index 468216fcc82c..d5d5c4000ebf 100644
--- a/java/webclient/src/BrowserControlMozillaShim.cpp
+++ b/java/webclient/src/BrowserControlNativeShim.cpp
@@ -26,11 +26,11 @@
*/
/*
- * BrowserControlMozillaShim.cpp
+ * BrowserControlNativeShim.cpp
*/
#include
-#include "BrowserControlMozillaShim.h"
+#include "BrowserControlNativeShim.h"
#ifdef XP_PC
#include
@@ -69,12 +69,6 @@ nsMacMessageSink gMessageSink;
#ifdef XP_UNIX
#include
#include "motif/MozillaEventThread.h"
-
-
-// debug: edburns: start
-#include
-// debug: edburns: end
-
#endif
#include "nsActions.h"
@@ -85,10 +79,6 @@ nsMacMessageSink gMessageSink;
#include "DocumentObserver.h"
#include "nsIDocumentLoader.h"
-#ifdef XP_UNIX
-#include "gtkmozarea.h"
-#endif
-
#ifdef XP_PC
#define APPSHELL_DLL "appshell.dll"
@@ -130,8 +120,7 @@ static NS_DEFINE_CID(kPrefCID, NS_PREF_CID);
extern "C" void NS_SetupRegistry();
extern nsresult NS_AutoregisterComponents();
-static nsFileSpec gRegistryFile;
-static nsFileSpec gComponentDir;
+static nsFileSpec gBinDir;
static nsISessionHistory *gHistory;
struct WebShellInitContext {
@@ -154,26 +143,6 @@ struct WebShellInitContext {
int h;
};
-#ifdef XP_UNIX
-
-void edburnsDebugBreak(void)
-{
- pid_t curPid = -1;
-
- if (-1 == (curPid = getpid())) {
- printf("can't get pid\n");
- return;
- }
-
- printf("dbx - %d\n\n", curPid);
- fflush(stdout);
- sleep(10);
-
- return;
-}
-
-#endif
-
void PostEvent (WebShellInitContext * initContext, PLEvent * event);
void * PostSynchronousEvent (WebShellInitContext * initContext, PLEvent * event);
@@ -361,21 +330,27 @@ EmbeddedEventHandler (void * arg) {
#if DEBUG_RAPTOR_CANVAS
printf("EmbeddedEventHandler(%lx): Init the WebShell...\n", initContext);
#endif
-
-#ifdef XP_UNIX
- rv = initContext->webShell->Init((nsNativeWidget *) GTK_MOZAREA(initContext->parentHWnd)->superwin,
- initContext->x, initContext->y,
- initContext->w, initContext->h);
-#else
+
rv = initContext->webShell->Init((nsNativeWidget *)initContext->parentHWnd,
- initContext->x, initContext->y,
- initContext->w, initContext->h);
-#endif
+ initContext->x, initContext->y, initContext->w, initContext->h);
if (NS_FAILED(rv)) {
initContext->initFailCode = kInitWebShellError;
return;
}
+ rv = initContext->webShell->SetContainer((nsIWebShellContainer *) initContext->webShell); // PENDING(edburns): I don't think this is correct.
+ if (NS_FAILED(rv)) {
+ initContext->initFailCode = kInitWebShellError;
+ return;
+ }
+
+ rv = initContext->webShell->SetWebShellType(nsWebShellChrome); // PENDING(edburns): I don't think this is correct.
+ if (NS_FAILED(rv)) {
+ initContext->initFailCode = kInitWebShellError;
+ return;
+ }
+
+
#if DEBUG_RAPTOR_CANVAS
printf("EmbeddedEventHandler(%lx): Install Prefs in the Webshell...\n", initContext);
#endif
@@ -405,7 +380,13 @@ EmbeddedEventHandler (void * arg) {
printf("EmbeddedEventHandler(%lx): Show the WebShell...\n", initContext);
#endif
- rv = initContext->webShell->Show();
+ nsActionEvent tAction(initContext->webShell);
+ nsIBrowserWindow *browserWindow = NULL;
+
+ if (NULL == (browserWindow = tAction.getBrowserWindow())) {
+ rv = browserWindow->Show();
+ browserWindow->Release();
+ }
if (NS_FAILED(rv)) {
initContext->initFailCode = kShowWebShellError;
return;
@@ -449,18 +430,6 @@ EmbeddedEventHandler (void * arg) {
void
InitEmbeddedEventHandler (WebShellInitContext* initContext)
{
-
- // this used to be in nativeInitialize
- // PENDING, assert that the registryFile and component Dir are valid
- NS_InitXPCOM(NULL, &gRegistryFile, &gComponentDir);
- NS_SetupRegistry();
- nsComponentManager::RegisterComponentLib(kSessionHistoryCID, NULL,
- NULL, APPSHELL_DLL,
- PR_FALSE, PR_FALSE);
- NS_AutoregisterComponents();
-
-
-
#if DEBUG_RAPTOR_CANVAS
printf("InitEmbeddedEventHandler(%lx): Creating embedded thread...\n", initContext);
#endif
@@ -711,12 +680,12 @@ extern "C" {
#endif
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorInitialize
* Signature: (Ljava/lang/String;)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize(
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeInitialize(
JNIEnv *env,
jobject obj,
jstring verifiedBinDirAbsolutePath)
@@ -724,28 +693,29 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize(
JNIEnv * pEnv = env;
jobject jobj = obj;
static PRBool gFirstTime = PR_TRUE;
-
if (gFirstTime)
{
- // set the gRegistryFile and gComponentDir correctly
const char *nativePath = (const char *) env->GetStringUTFChars(verifiedBinDirAbsolutePath, 0);
- gRegistryFile = nativePath;
- gRegistryFile += "component.reg";
- gComponentDir = nativePath;
- gComponentDir += "components";
+ gBinDir = nativePath;
+ NS_InitXPCOM(NULL, &gBinDir, NULL);
+ NS_SetupRegistry();
+ nsComponentManager::RegisterComponentLib(kSessionHistoryCID, NULL,
+ NULL, APPSHELL_DLL,
+ PR_FALSE, PR_FALSE);
+ NS_AutoregisterComponents();
gFirstTime = PR_FALSE;
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeInitialize()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorTerminate
* Signature: ()V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeTerminate (
JNIEnv * env,
jobject obj)
{
@@ -756,438 +726,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate (
printf("raptorTerminate() called\n");
#endif
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeTerminate()
/*
- * Class: BrowserControlMozillaShim
- * Method: raptorSendKeyDownEvent
- * Signature: (ICIII)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jchar keyChar,
- jint keyCode,
- jint modifiers,
- jint eventTime)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
- nsKeyEvent keyEvent;
-#ifdef XP_MAC
- EventRecord event;
-
- event.what = ::keyDown;
- event.message = ConvertKeys(keyChar, keyCode);
-// event.when = (unsigned long) eventTime;
- event.when = TickCount();
- event.where.h = 0;
- event.where.v = 0;
- event.modifiers = ConvertModifiersToMacModifiers(modifiers);
- keyEvent.nativeMsg = &event;
-#else
- keyEvent.nativeMsg = nsnull;
-#endif
- // nsEvent
- keyEvent.eventStructType = NS_KEY_EVENT;
- keyEvent.message = NS_KEY_DOWN;
- keyEvent.point.x = 0;
- keyEvent.point.y = 0;
- // keyEvent.time = TickCount();
- // nsGUIEvent
- keyEvent.widget = (nsIWidget *) widgetPtr;
-
- // nsInputEvent
- ConvertModifiersTo_nsInputEvent(modifiers, keyEvent);
- // nsKeyEvent
- keyEvent.keyCode = (PRUint32) keyCode;
- keyEvent.charCode = (PRUint32) keyChar;
-
- DispatchEvent(&keyEvent, keyEvent.widget);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorSendKeyUpEvent
- * Signature: (ICIII)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jchar keyChar,
- jint keyCode,
- jint modifiers,
- jint eventTime)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
- nsKeyEvent keyEvent;
-
-#ifdef XP_MAC
- EventRecord event;
-
- event.what = ::keyUp;
- event.message = ConvertKeys(keyChar, keyCode);
-// event.when = (unsigned long) eventTime;
- event.when = TickCount();
- event.where.h = 0;
- event.where.v = 0;
- event.modifiers = ConvertModifiersToMacModifiers(modifiers);
-
- keyEvent.nativeMsg = &event;
-#else
- keyEvent.nativeMsg = nsnull;
-#endif
-
- // nsEvent
- keyEvent.eventStructType = NS_KEY_EVENT;
- keyEvent.message = NS_KEY_UP;
- keyEvent.point.x = 0;
- keyEvent.point.y = 0;
-#if 0
- keyEvent.time = TickCount();
-#endif
-
- // nsGUIEvent
- keyEvent.widget = (nsIWidget *) widgetPtr;
-
- // nsInputEvent
- ConvertModifiersTo_nsInputEvent(modifiers, keyEvent);
-
- // nsKeyEvent
- keyEvent.keyCode = (PRUint32) keyCode;
- keyEvent.charCode = (PRUint32) keyChar;
-
- DispatchEvent(&keyEvent, keyEvent.widget);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorSendMouseEvent
- * Signature: (IIIIIIIIIII)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent (
- JNIEnv * env,
- jobject obj,
- jint windowPtr,
- jint widgetPtr,
- jint widgetX,
- jint widgetY,
- jint windowX,
- jint windowY,
- jint mouseMessage,
- jint numClicks,
- jint modifiers,
- jint eventTime)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
- nsMouseEvent mouseEvent;
-
-#ifdef XP_MAC
- EventRecord event;
- Point pt;
-
- ConvertMouseCoordsToMacMouseCoords(windowPtr, windowX, windowY, pt);
-
- event.what = ConvertMouseMessageToMacMouseEvent(mouseMessage);
- event.message = 0;
-// event.when = (unsigned long) eventTime;
- event.when = TickCount();
- event.where = pt;
- event.modifiers = ConvertModifiersToMacModifiers(modifiers);
-
- mouseEvent.nativeMsg = &event;
- mouseEvent.time = TickCount();
-#else
- mouseEvent.nativeMsg = nsnull;
-#endif
-
- // nsEvent
- mouseEvent.eventStructType = NS_MOUSE_EVENT;
- mouseEvent.message = ConvertMouseMessageTo_nsMouseMessage(mouseMessage, modifiers, numClicks);
- mouseEvent.point.x = widgetX;
- mouseEvent.point.y = widgetY;
-
- // nsGUIEvent
- mouseEvent.widget = (nsIWidget *) widgetPtr;
-
- // nsInputEvent
- ConvertModifiersTo_nsInputEvent(modifiers, mouseEvent);
-
- // nsMouseEvent
- mouseEvent.clickCount = (PRUint32) numClicks;
-
- DispatchEvent(&mouseEvent, mouseEvent.widget);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent()
-
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorIdleEvent
- * Signature: (I)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeIdleEvent (
- JNIEnv * env,
- jobject obj,
- jint windowPtr,
- jint eventTime)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-#ifdef XP_MAC
- EventRecord event;
-
- event.what = ::nullEvent;
- event.message = 0;
-// event.when = (unsigned long) eventTime;
- event.when = TickCount();
- event.where.h = 0;
- event.where.v = 0;
- event.modifiers = 0;
-
- gMessageSink.DispatchOSEvent(event, (WindowPtr) windowPtr);
-
- // Enable Raptor background activity
- // Note: This will be moved to nsMacMessageSink very soon.
- // The application will not have to do it anymore.
-
- Repeater::DoRepeaters(event);
- Repeater::DoIdlers(event);
-#endif
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeIdleEvent()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorUpdateEvent
- * Signature: (II)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeUpdateEvent (
- JNIEnv * env,
- jobject obj,
- jint windowPtr,
- jint eventTime)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-#ifdef XP_MAC
- EventRecord event;
-
- event.what = ::updateEvt;
- event.message = 0;
-// event.when = (unsigned long) eventTime;
- event.when = TickCount();
- event.where.h = 0;
- event.where.v = 0;
- event.modifiers = 0;
-
- gMessageSink.DispatchOSEvent(event, (WindowPtr) windowPtr);
-#endif
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeUpdateEvent()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetCreate
- * Signature: (I)I
- */
-JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate (
- JNIEnv * env,
- jobject obj,
- jint windowPtr,
- jint x,
- jint y,
- jint width,
- jint height)
-{
- jobject jobj = obj;
- nsIWidget* widgetPtr = NULL;
-#ifdef XP_MAC
- WindowPtr pWindow = (WindowPtr) windowPtr;
-#elif defined(XP_PC)
- HWND pWindow = (HWND) windowPtr;
-#elif defined(XP_UNIX)
- GtkWidget * pWindow = (GtkWidget *) windowPtr;
-#endif
- nsRect r(x, y, width, height);
- nsresult rv;
-
- // create top-level widget
- // IMPORTANT: It must be created before any controls are added to the window
-
- rv = nsComponentManager::CreateInstance(kWindowCID, nsnull, kIWidgetIID, (void**)&widgetPtr);
- if (rv != NS_OK)
- {
- ::ThrowExceptionToJava(env, "raptorWidgetCreate Exception: unable to create widget instance");
- return 0;
- }
-
- rv = widgetPtr->Create((nsNativeWidget)pWindow, r, HandleRaptorEvent, nsnull);
- if (rv != NS_OK)
- {
- ::ThrowExceptionToJava(env, "raptorWidgetCreate Exception: unable to create widget");
- return 0;
- }
-
- return (jint) widgetPtr;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetDelete
- * Signature: (I)I
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetDelete (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
- if (widgetPtr)
- {
- delete ((nsIWidget *) widgetPtr);
- }
-}
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetResize
- * Signature: (IIIZ)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jint x,
- jint y,
- jint width,
- jint height,
- jboolean repaint)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-
- ((nsIWidget *) widgetPtr)->Resize((PRUint32) x, (PRUint32) y, (PRUint32) width, (PRUint32) height, (PRBool) repaint);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize()
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetEnable
- * Signature: (IZ)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetEnable (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jboolean enable)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-
- ((nsIWidget *) widgetPtr)->Enable((PRBool) enable);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetEnable()
-
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetShow
- * Signature: (IZ)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetShow (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jboolean show)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-
- ((nsIWidget *) widgetPtr)->Show((PRBool) show);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetShow()
-
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetInvalidate
- * Signature: (IZ)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetInvalidate (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr,
- jboolean isSynchronous)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-
- ((nsIWidget *) widgetPtr)->Invalidate((PRBool) isSynchronous);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetInvalidate()
-
-
-
-/*
- * Class: BrowserControlMozillaShim
- * Method: raptorWidgetUpdate
- * Signature: (I)V
- */
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetUpdate (
- JNIEnv * env,
- jobject obj,
- jint widgetPtr)
-{
- JNIEnv * pEnv = env;
- jobject jobj = obj;
-
- ((nsIWidget *) widgetPtr)->Update();
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetUpdate()
-
-
-
-JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeProcessEvents (
- JNIEnv* env,
- jobject obj,
- jint theWebShell)
-{
- JNIEnv* pEnv = env;
- jobject jobj = obj;
-
-// WebShellInitContext* initContext = (WebShellInitContext *) theWebShell;
-// initContext->webShell->Show();
-}
-
-
-/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellCreate
* Signature: (IIIIII)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCreate (
JNIEnv * env,
jobject obj,
jint windowPtr,
@@ -1273,16 +821,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate (
#endif
return (jint) initContext;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCreate()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellDelete
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellDelete (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1308,16 +856,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete (
::ThrowExceptionToJava(env, "Exception: null webShellPtr passed to raptorWebShellDelete");
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellDelete()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellLoadURL
* Signature: (ILjava/lang/String;)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellLoadURL (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1356,16 +904,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL (
}
env->ReleaseStringChars(urlString, urlStringChars);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellLoadURL()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellStop
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellStop (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1386,16 +934,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellStop()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellShow
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellShow (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1416,16 +964,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellShow()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellHide
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellHide (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1447,16 +995,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellHide()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellSetBounds
* Signature: (IIIII)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetBounds (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1482,16 +1030,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetBounds()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellMoveTo
* Signature: (III)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellMoveTo (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1515,16 +1063,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellMoveTo()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellSetFocus
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetFocus (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1546,16 +1094,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetFocus()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellRemoveFocus
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRemoveFocus (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1577,16 +1125,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRemoveFocus()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellRepaint
* Signature: (IZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRepaint (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1609,16 +1157,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint (
::PostEvent(initContext, event);
}
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRepaint()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellCanBack
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanBack (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1644,16 +1192,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack (
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanBack()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellCanForward
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanForward (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1679,16 +1227,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward (
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanForward()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellBack
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1714,10 +1262,10 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack (
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack()
JNIEXPORT jboolean JNICALL
- Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellAddDocListener
+ Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellAddDocListener
(JNIEnv *env,
jobject obj,
jint webShellPtr,
@@ -1747,12 +1295,12 @@ JNIEXPORT jboolean JNICALL
}
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellForward
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellForward (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1778,16 +1326,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward (
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellForward()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellGoTo
* Signature: (II)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGoTo (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1795,7 +1343,7 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo (
{
JNIEnv * pEnv = env;
jobject jobj = obj;
- void * voidResult = nsnull;
+ void * voidResult = nsnull;
WebShellInitContext* initContext = (WebShellInitContext *) webShellPtr;
@@ -1814,16 +1362,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo (
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGoTo()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellGetHistoryLength
* Signature: (I)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLength (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryLength (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1849,16 +1397,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLen
}
return 0;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLength()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryLength()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellGetHistoryIndex
* Signature: (I)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryIndex (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryIndex (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1884,16 +1432,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryInd
}
return 0;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryIndex()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryIndex()
/*
- * Class: BrowserControlMozillaShim
+ * Class: BrowserControlNativeShim
* Method: raptorWebShellGetURL
* Signature: (II)Ljava/lang/String;
*/
JNIEXPORT jstring JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetURL (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -1948,16 +1496,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL (
}
return urlString;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetURL()
// added my Mark Goddard OTMP 9/2/1999
/*
- * Class: org_mozilla_webclient_BrowserControlMozillaShim
+ * Class: org_mozilla_webclient_BrowserControlNativeShim
* Method: nativeWebShellRefresh
* Signature: (I)V
*/
JNIEXPORT jboolean JNICALL
- Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRefresh (
+ Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRefresh (
JNIEnv * env,
jobject obj,
jint webShellPtr)
@@ -1983,7 +1531,7 @@ JNIEXPORT jboolean JNICALL
}
return JNI_FALSE;
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack()
#ifdef XP_UNIX
@@ -2008,22 +1556,18 @@ JNIEXPORT void JNICALL Java_org_mozilla_webclient_motif_MozillaEventThread_proce
#endif
/*
- * Class: org_mozilla_webclient_BrowserControlMozillaShim
+ * Class: org_mozilla_webclient_BrowserControlNativeShim
* Method: nativeDebugBreak
* Signature: (Ljava/lang/String;I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeDebugBreak(JNIEnv *jEnv,
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeDebugBreak(JNIEnv *jEnv,
jclass myClass,
jstring fileName,
jint lineNumber)
{
const char *charFileName = (char *) jEnv->GetStringUTFChars(fileName, 0);
nsDebug::Break(charFileName, lineNumber);
-#ifdef XP_UNIX
- edburnsDebugBreak();
-#endif
-
}
diff --git a/java/webclient/src/Makefile.win b/java/webclient/src/Makefile.win
index c89bcd3043b4..d6d3811153c0 100644
--- a/java/webclient/src/Makefile.win
+++ b/java/webclient/src/Makefile.win
@@ -30,7 +30,7 @@ MODULE=webclient
OBJS = \
.\$(OBJDIR)\nsActions.obj \
- .\$(OBJDIR)\BrowserControlMozillaShim.obj \
+ .\$(OBJDIR)\BrowserControlNativeShim.obj \
.\$(OBJDIR)\DocumentObserver.obj \
.\$(OBJDIR)\jni_util.obj \
$(NULL)
@@ -66,11 +66,11 @@ include <$(DEPTH)\java\config\localdefs.mak>
!CMDSWITCHES -S
# generate the jni header
-export:: BrowserControlMozillaShim.h
+export:: BrowserControlNativeShim.h
-BrowserControlMozillaShim.h:
- @echo Assuming class org.mozilla.webclient.BrowserControlMozillaShim is in $(JAVAH_FLAGS)
- $(JAVAH) $(JAVAH_FLAGS) -o $@ org.mozilla.webclient.BrowserControlMozillaShim
+BrowserControlNativeShim.h:
+ @echo Assuming class org.mozilla.webclient.BrowserControlNativeShim is in $(JAVAH_FLAGS)
+ $(JAVAH) $(JAVAH_FLAGS) -o $@ org.mozilla.webclient.BrowserControlNativeShim
install:: $(DLL)
$(MAKE_INSTALL) .\$(OBJDIR)\$(DLLNAME).dll $(DIST)\bin
@@ -85,6 +85,6 @@ clobber_all:: clobber
clobber::
rm -f $(DIST)\bin\$(DLLNAME).dll
- rm -f BrowserControlMozillaShim.h
+ rm -f BrowserControlNativeShim.h
rm -f .\$(OBJDIR)\runem.bat
rm -f .\$(OBJDIR)\swingem.bat
diff --git a/java/webclient/src/motif/BrowserControlMozillaShimStub.cpp b/java/webclient/src/motif/BrowserControlNativeShimStub.cpp
similarity index 64%
rename from java/webclient/src/motif/BrowserControlMozillaShimStub.cpp
rename to java/webclient/src/motif/BrowserControlNativeShimStub.cpp
index 7c839847dd66..ac0b047ea69c 100644
--- a/java/webclient/src/motif/BrowserControlMozillaShimStub.cpp
+++ b/java/webclient/src/motif/BrowserControlNativeShimStub.cpp
@@ -21,7 +21,7 @@
*/
/*
- * BrowserControlMozillaShimStub.cpp
+ * BrowserControlNativeShimStub.cpp
*/
// PENDING(mark): I suppose this is where I need to go into my explaination of why
@@ -32,12 +32,12 @@
// JNI...yada, yada, yada
#include
// JNI Header
-#include "../BrowserControlMozillaShim.h"
+#include "../BrowserControlNativeShim.h"
// JNI Header
-#include "MozillaEventThread.h"
+#include "NativeEventThread.h"
// allow code in webclientstub.so to load us
-#include "BrowserControlMozillaShimStub.h"
+#include "BrowserControlNativeShimStub.h"
// Global reference to webclient dll
void * webClientDll;
@@ -85,167 +85,167 @@ void (* processNativeEventQueue) (JNIEnv *, jobject, jint);
void locateBrowserControlStubFunctions(void * dll) {
- nativeInitialize = (void (*) (JNIEnv *, jobject, jstring)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize");
+ nativeInitialize = (void (*) (JNIEnv *, jobject, jstring)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeInitialize");
if (!nativeInitialize) {
printf("got dlsym error %s\n", dlerror());
}
- nativeTerminate = (void (*) (JNIEnv *, jobject)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate");
+ nativeTerminate = (void (*) (JNIEnv *, jobject)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeTerminate");
if (!nativeTerminate) {
printf("got dlsym error %s\n", dlerror());
}
- nativeSendKeyDownEvent = (void (*) (JNIEnv *, jobject, jint, jchar, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent");
+ nativeSendKeyDownEvent = (void (*) (JNIEnv *, jobject, jint, jchar, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyDownEvent");
if (!nativeSendKeyDownEvent) {
printf("got dlsym error %s\n", dlerror());
}
- nativeSendKeyUpEvent = (void (*) (JNIEnv *, jobject, jint, jchar, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent");
+ nativeSendKeyUpEvent = (void (*) (JNIEnv *, jobject, jint, jchar, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyUpEvent");
if (!nativeSendKeyUpEvent) {
printf("got dlsym error %s\n", dlerror());
}
- nativeSendMouseEvent = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint, jint, jint, jint,jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent");
+ nativeSendMouseEvent = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint, jint, jint, jint,jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendMouseEvent");
if (!nativeSendMouseEvent) {
printf("got dlsym error %s\n", dlerror());
}
- nativeIdleEvent = (void (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeIdleEvent");
+ nativeIdleEvent = (void (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeIdleEvent");
if (!nativeIdleEvent) {
printf("got dlsym error %s\n", dlerror());
}
- nativeUpdateEvent = (void (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeUpdateEvent");
+ nativeUpdateEvent = (void (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeUpdateEvent");
if (!nativeUpdateEvent) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetCreate = (jint (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate");
+ nativeWidgetCreate = (jint (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetCreate");
if (!nativeWidgetCreate) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetDelete = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetDelete");
+ nativeWidgetDelete = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetDelete");
if (!nativeWidgetDelete) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetResize = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize");
+ nativeWidgetResize = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetResize");
if (!nativeWidgetResize) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetEnable = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetEnable");
+ nativeWidgetEnable = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetEnable");
if (!nativeWidgetEnable) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetShow = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetShow");
+ nativeWidgetShow = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetShow");
if (!nativeWidgetShow) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetInvalidate = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetInvalidate");
+ nativeWidgetInvalidate = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetInvalidate");
if (!nativeWidgetInvalidate) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWidgetUpdate = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetUpdate");
+ nativeWidgetUpdate = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetUpdate");
if (!nativeWidgetUpdate) {
printf("got dlsym error %s\n", dlerror());
}
- nativeProcessEvents = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeProcessEvents");
+ nativeProcessEvents = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeProcessEvents");
if (!nativeProcessEvents) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellCreate = (jint (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate");
+ nativeWebShellCreate = (jint (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCreate");
if (!nativeWebShellCreate) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellDelete = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete");
+ nativeWebShellDelete = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellDelete");
if (!nativeWebShellDelete) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellLoadURL = (void (*) (JNIEnv *, jobject, jint, jstring)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL");
+ nativeWebShellLoadURL = (void (*) (JNIEnv *, jobject, jint, jstring)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellLoadURL");
if (!nativeWebShellLoadURL) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellStop = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop");
+ nativeWebShellStop = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellStop");
if (!nativeWebShellStop) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellShow = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow");
+ nativeWebShellShow = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellShow");
if (!nativeWebShellShow) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellHide = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide");
+ nativeWebShellHide = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellHide");
if (!nativeWebShellHide) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellSetBounds = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds");
+ nativeWebShellSetBounds = (void (*) (JNIEnv *, jobject, jint, jint, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetBounds");
if (!nativeWebShellSetBounds) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellMoveTo = (void (*) (JNIEnv *, jobject, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo");
+ nativeWebShellMoveTo = (void (*) (JNIEnv *, jobject, jint, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellMoveTo");
if (!nativeWebShellMoveTo) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellSetFocus = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus");
+ nativeWebShellSetFocus = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetFocus");
if (!nativeWebShellSetFocus) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellRemoveFocus = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus");
+ nativeWebShellRemoveFocus = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRemoveFocus");
if (!nativeWebShellRemoveFocus) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellRepaint = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint");
+ nativeWebShellRepaint = (void (*) (JNIEnv *, jobject, jint, jboolean)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRepaint");
if (!nativeWebShellRepaint) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellCanBack = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack");
+ nativeWebShellCanBack = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanBack");
if (!nativeWebShellCanBack) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellCanForward = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward");
+ nativeWebShellCanForward = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanForward");
if (!nativeWebShellCanForward) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellBack = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack");
+ nativeWebShellBack = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack");
if (!nativeWebShellBack) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellForward = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward");
+ nativeWebShellForward = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellForward");
if (!nativeWebShellForward) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellGoTo = (jboolean (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo");
+ nativeWebShellGoTo = (jboolean (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGoTo");
if (!nativeWebShellGoTo) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellGetHistoryLength = (jint (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLength");
+ nativeWebShellGetHistoryLength = (jint (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryLength");
if (!nativeWebShellGetHistoryLength) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellGetHistoryIndex = (jint (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryIndex");
+ nativeWebShellGetHistoryIndex = (jint (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryIndex");
if (!nativeWebShellGetHistoryIndex) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellGetURL = (jstring (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL");
+ nativeWebShellGetURL = (jstring (*) (JNIEnv *, jobject, jint, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetURL");
if (!nativeWebShellGetURL) {
printf("got dlsym error %s\n", dlerror());
}
// added by Mark Goddard OTMP 9/2/1999
- nativeWebShellRefresh = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRefresh");
+ nativeWebShellRefresh = (jboolean (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRefresh");
if (!nativeWebShellRefresh) {
printf("got dlsym error %s\n", dlerror());
}
- nativeWebShellAddDocListener = (jboolean (*) (JNIEnv *, jobject, jint, jobject)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellAddDocListener");
+ nativeWebShellAddDocListener = (jboolean (*) (JNIEnv *, jobject, jint, jobject)) dlsym(dll, "Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellAddDocListener");
if (!nativeWebShellAddDocListener) {
printf("got dlsym error %s\n", dlerror());
}
- processNativeEventQueue = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_motif_MozillaEventThread_processNativeEventQueue");
+ processNativeEventQueue = (void (*) (JNIEnv *, jobject, jint)) dlsym(dll, "Java_org_mozilla_webclient_motif_NativeEventThread_processNativeEventQueue");
if (!processNativeEventQueue) {
printf("got dlsym error %s\n", dlerror());
}
}
/*
- * Class: org_mozilla_webclient_motif_MotifMozillaEventQueue
+ * Class: org_mozilla_webclient_motif_MotifNativeEventQueue
* Method: processNativeEventQueue
* Signature: ()V
*/
-JNIEXPORT void JNICALL Java_org_mozilla_webclient_motif_MozillaEventThread_processNativeEventQueue
+JNIEXPORT void JNICALL Java_org_mozilla_webclient_motif_NativeEventThread_processNativeEventQueue
(JNIEnv * env, jobject obj, jint gtkWinPtr) {
(* processNativeEventQueue) (env, obj, gtkWinPtr);
}
@@ -265,41 +265,41 @@ void loadMainDll(void)
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorInitialize
* Signature: ()V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeInitialize (
JNIEnv * env,
jobject obj, jstring verifiedBinDirAbsolutePath)
{
(* nativeInitialize) (env, obj, verifiedBinDirAbsolutePath);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeInitialize()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeInitialize()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorTerminate
* Signature: ()V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeTerminate (
JNIEnv * env,
jobject obj)
{
(* nativeTerminate) (env, obj);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeTerminate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeTerminate()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorSendKeyDownEvent
* Signature: (ICIII)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyDownEvent (
JNIEnv * env,
jobject obj,
jint widgetPtr,
@@ -309,16 +309,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent (
jint eventTime)
{
(* nativeSendKeyDownEvent) (env, obj, widgetPtr, keyChar, keyCode, modifiers, eventTime);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyDownEvent()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyDownEvent()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorSendKeyUpEvent
* Signature: (ICIII)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyUpEvent (
JNIEnv * env,
jobject obj,
jint widgetPtr,
@@ -328,16 +328,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent (
jint eventTime)
{
(* nativeSendKeyUpEvent) (env, obj, widgetPtr, keyChar, keyCode, modifiers, eventTime);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendKeyUpEvent()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendKeyUpEvent()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorSendMouseEvent
* Signature: (IIIIIIIIIII)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendMouseEvent (
JNIEnv * env,
jobject obj,
jint windowPtr,
@@ -352,49 +352,49 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent (
jint eventTime)
{
(* nativeSendMouseEvent) (env, obj, windowPtr, widgetPtr, widgetX, widgetY, windowX, windowY, mouseMessage, numClicks, modifiers, eventTime);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeSendMouseEvent()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeSendMouseEvent()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorIdleEvent
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeIdleEvent (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeIdleEvent (
JNIEnv * env,
jobject obj,
jint windowPtr,
jint eventTime)
{
(* nativeIdleEvent) (env, obj, windowPtr, eventTime);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeIdleEvent()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeIdleEvent()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorUpdateEvent
* Signature: (II)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeUpdateEvent (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeUpdateEvent (
JNIEnv * env,
jobject obj,
jint windowPtr,
jint eventTime)
{
(* nativeUpdateEvent) (env, obj, windowPtr, eventTime);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeUpdateEvent()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeUpdateEvent()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetCreate
* Signature: (I)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetCreate (
JNIEnv * env,
jobject obj,
jint windowPtr,
@@ -404,32 +404,32 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate (
jint height)
{
return (* nativeWidgetCreate) (env, obj, windowPtr, x, y, width, height);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetCreate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetCreate()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetDelete
* Signature: (I)I
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetDelete (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetDelete (
JNIEnv * env,
jobject obj,
jint widgetPtr)
{
(* nativeWidgetDelete) (env, obj, widgetPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetDelete()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetDelete()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetResize
* Signature: (IIIZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetResize (
JNIEnv * env,
jobject obj,
jint widgetPtr,
@@ -440,79 +440,79 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize (
jboolean repaint)
{
(* nativeWidgetResize) (env, obj, widgetPtr, x, y, width, height, repaint);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetResize()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetResize()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetEnable
* Signature: (IZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetEnable (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetEnable (
JNIEnv * env,
jobject obj,
jint widgetPtr,
jboolean enable)
{
(* nativeWidgetEnable) (env, obj, widgetPtr, enable);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetEnable()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetEnable()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetShow
* Signature: (IZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetShow (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetShow (
JNIEnv * env,
jobject obj,
jint widgetPtr,
jboolean show)
{
(* nativeWidgetShow) (env, obj, widgetPtr, show);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetShow()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetShow()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetInvalidate
* Signature: (IZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetInvalidate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetInvalidate (
JNIEnv * env,
jobject obj,
jint widgetPtr,
jboolean isSynchronous)
{
(* nativeWidgetInvalidate) (env, obj, widgetPtr, isSynchronous);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetInvalidate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetInvalidate()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWidgetUpdate
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetUpdate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetUpdate (
JNIEnv * env,
jobject obj,
jint widgetPtr)
{
(* nativeWidgetUpdate) (env, obj, widgetPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWidgetUpdate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWidgetUpdate()
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeProcessEvents (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeProcessEvents (
JNIEnv* env,
jobject obj,
jint theWebShell)
@@ -522,12 +522,12 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeProcessEvents (
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellCreate
* Signature: (IIIIII)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCreate (
JNIEnv * env,
jobject obj,
jint windowPtr,
@@ -537,92 +537,92 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate (
jint height)
{
return (* nativeWebShellCreate) (env, obj, windowPtr, x, y, width, height);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCreate()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCreate()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellDelete
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellDelete (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellDelete) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellDelete()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellDelete()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellLoadURL
* Signature: (ILjava/lang/String;)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellLoadURL (
JNIEnv * env,
jobject obj,
jint webShellPtr,
jstring urlString)
{
(* nativeWebShellLoadURL) (env, obj, webShellPtr, urlString);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellLoadURL()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellLoadURL()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellStop
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellStop (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellStop) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellStop()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellStop()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellShow
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellShow (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellShow) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellShow()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellShow()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellHide
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellHide (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellHide) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellHide()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellHide()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellSetBounds
* Signature: (IIIII)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetBounds (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -632,16 +632,16 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds (
jint height)
{
(* nativeWebShellSetBounds) (env, obj, webShellPtr, x, y, width, height);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetBounds()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetBounds()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellMoveTo
* Signature: (III)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellMoveTo (
JNIEnv * env,
jobject obj,
jint webShellPtr,
@@ -649,206 +649,206 @@ Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo (
jint y)
{
(* nativeWebShellMoveTo) (env, obj, webShellPtr, x, y);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellMoveTo()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellMoveTo()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellSetFocus
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetFocus (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellSetFocus) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellSetFocus()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellSetFocus()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellRemoveFocus
* Signature: (I)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRemoveFocus (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
(* nativeWebShellRemoveFocus) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRemoveFocus()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRemoveFocus()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellRepaint
* Signature: (IZ)V
*/
JNIEXPORT void JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRepaint (
JNIEnv * env,
jobject obj,
jint webShellPtr,
jboolean forceRepaint)
{
(* nativeWebShellRepaint) (env, obj, webShellPtr, forceRepaint);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRepaint()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRepaint()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellCanBack
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanBack (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellCanBack) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanBack()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanBack()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellCanForward
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanForward (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellCanForward) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellCanForward()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellCanForward()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellBack
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellBack) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellBack()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellBack()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellForward
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellForward (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellForward) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellForward()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellForward()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellGoTo
* Signature: (II)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGoTo (
JNIEnv * env,
jobject obj,
jint webShellPtr,
jint historyIndex)
{
return (* nativeWebShellGoTo) (env, obj, webShellPtr, historyIndex);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGoTo()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGoTo()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellGetHistoryLength
* Signature: (I)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLength (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryLength (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellGetHistoryLength) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryLength()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryLength()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellGetHistoryIndex
* Signature: (I)I
*/
JNIEXPORT jint JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryIndex (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryIndex (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellGetHistoryIndex) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetHistoryIndex()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetHistoryIndex()
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellGetURL
* Signature: (II)Ljava/lang/String;
*/
JNIEXPORT jstring JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetURL (
JNIEnv * env,
jobject obj,
jint webShellPtr,
jint historyIndex)
{
return (* nativeWebShellGetURL) (env, obj, webShellPtr, historyIndex);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellGetURL()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellGetURL()
// added by Mark Goddard OTMP 9/2/1999
/*
- * Class: MozWebShellMozillaShim
+ * Class: MozWebShellNativeShim
* Method: raptorWebShellRefresh
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRefresh (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRefresh (
JNIEnv * env,
jobject obj,
jint webShellPtr)
{
return (* nativeWebShellRefresh) (env, obj, webShellPtr);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellRefresh()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellRefresh()
/*
- * Class: BrowserControlMozillaShimStub
+ * Class: BrowserControlNativeShimStub
* Method: nativeWebShellAddDocListener
* Signature: (I)Z
*/
JNIEXPORT jboolean JNICALL
-Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellAddDocListener (
+Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellAddDocListener (
JNIEnv * env,
jobject obj,
jint webShellPtr,
jobject listener)
{
return (* nativeWebShellAddDocListener) (env, obj, webShellPtr, listener);
-} // Java_org_mozilla_webclient_BrowserControlMozillaShim_nativeWebShellAddDocListener()
+} // Java_org_mozilla_webclient_BrowserControlNativeShim_nativeWebShellAddDocListener()
// EOF
diff --git a/java/webclient/src/motif/BrowserControlMozillaShimStub.h b/java/webclient/src/motif/BrowserControlNativeShimStub.h
similarity index 97%
rename from java/webclient/src/motif/BrowserControlMozillaShimStub.h
rename to java/webclient/src/motif/BrowserControlNativeShimStub.h
index 71415641b48e..b01cb5d60894 100644
--- a/java/webclient/src/motif/BrowserControlMozillaShimStub.h
+++ b/java/webclient/src/motif/BrowserControlNativeShimStub.h
@@ -21,7 +21,7 @@
*/
/*
- * BrowserControlMozillaShimStub.h
+ * BrowserControlNativeShimStub.h
*/
/*
diff --git a/java/webclient/classes/org/mozilla/webclient/motif/MozillaEventThread.java b/java/webclient/classes/org/mozilla/webclient/motif/NativeEventThread.java
similarity index 90%
rename from java/webclient/classes/org/mozilla/webclient/motif/MozillaEventThread.java
rename to java/webclient/classes/org/mozilla/webclient/motif/NativeEventThread.java
index dd6dd08b7346..29bd6a5baa94 100644
--- a/java/webclient/classes/org/mozilla/webclient/motif/MozillaEventThread.java
+++ b/java/webclient/classes/org/mozilla/webclient/motif/NativeEventThread.java
@@ -23,7 +23,7 @@ package org.mozilla.webclient.motif;
/**
* This is MozillaEventThread. It's job is to process any pending mozilla events
* which have been queued up.
*
* It also contains a private static hashtable mapping of GTK window to
@@ -38,14 +38,14 @@ package org.mozilla.webclient.motif;
* Lifetime And Scope
* There will be one of these per BrowserControlCanvas (but hasn't been tested yet)
*
- * @version $Id: MozillaEventThread.java,v 1.3 1999/11/06 02:24:19 dmose%mozilla.org Exp $
- * @see org.mozilla.webclient.motif.MozillaEventThread
+ * @version $Id: NativeEventThread.java,v 1.1 1999/12/23 04:09:31 edburns%acm.org Exp $
+ * @see org.mozilla.webclient.motif.NativeEventThread
*
*/
import java.util.*;
-public class MozillaEventThread extends Thread {
+public class NativeEventThread extends Thread {
static private int eventQueueCount = 0;
// A mapping of gtkWindowID <-> WebShellInitContext structs
@@ -75,7 +75,7 @@ public class MozillaEventThread extends Thread {
return 0;
}
- public MozillaEventThread(MotifBrowserControlCanvas canvas) {
+ public NativeEventThread(MotifBrowserControlCanvas canvas) {
super("Mozilla-Event-Thread-" + eventQueueCount);
this.browserCanvas = canvas;
@@ -23,7 +23,7 @@ package org.mozilla.webclient.motif;
/**
- * This is MozillaEventThread. It's job is to process any pending mozilla events
+ * This is NativeEventThread. It's job is to process any pending mozilla events
* which have been queued up.
*